@@ -36,7 +36,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.024'; # VERSION
+our $VERSION = '0.025'; # VERSION
 
 use Mouse;
 use FileHandle;
@@ -64,6 +64,10 @@ sub _finish_stanza
     return;
   }
 
+  if ($current->{is_obsolete}) {
+    delete $current->{alt_id};
+  }
+
   $current->{metadata} = $metadata_ref;
   $current->{source_file} = $filename;
   $current->{relationship} //= [];
